<?php

/**
 * @file
 * Contains \Drupal\field_wistia\Form\FieldWistiaSettingsForm.
 */

namespace Drupal\field_wistia\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;


class FieldWistiaSettingsForm extends ConfigFormBase
{

  /**
   * Gets the configuration names that will be editable.
   *
   * @return array
   *   An array of configuration object names that are editable if called in
   *   conjunction with the trait's config() method.
   */
  protected function getEditableConfigNames()
  {
    return ['field_wistia.settings'];
  }

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId()
  {
    return 'wistia_settings';
  }

  public function buildForm(array $form, FormStateInterface $form_state)
  {
    $config = $this->configFactory->get('field_wistia.settings');
    $form['text'] = array(
      '#type' => 'markup',
      '#markup' => '<p>' . t('The following settings will be used as default
        values on all Wistia video fields.  Many of these settings can be
        overridden on a per-field basis.') . '</p>',
    );
    $form['field_wistia_global'] = array(
      '#type' => 'fieldset',
      '#title' => t('Video parameters'),
    );
    $form['field_wistia_global']['field_wistia_embed_type'] = array(
      '#title' => t('Set Default Embed Type'),
      '#type' => 'radios',
      '#options' => array(
        'iframe' => t('iFrame'),
        'async' => t('Async'),
        'async_popover' => t('Async Popover'),
      ),
      '#default_value' => $config->get('field_wistia_embed_type'),
      '#description' => t('For more information on the embed types 
        see the <a href="@api_reference">Wisita embed documentation</a>.',
        array(
          '@api_reference' => 'https://wistia.com/support/developers/construct-an-embed-code#embed-code-types',
        )),
    );

    return parent::buildForm($form, $form_state); // TODO: Change the autogenerated stub

  }

  public function submitForm(array &$form, FormStateInterface $form_state)
  {
    $values = $form_state->getValues();
    \Drupal::configFactory()->getEditable('field_wistia.settings')
      ->set('field_wistia_embed_type', $values['field_wistia_embed_type'])
      ->save();

    parent::submitForm($form, $form_state); // TODO: Change the autogenerated stub

  }

}
